@@ -2,16 +2,11 @@
 // Reworked by Klaus Umbach, klaus.umbach@gmx.net and
 // Moritz Bunkus, moritz@bunkus.org
 
-// In synch with rev 1.91 (Moritz Bunkus)
+// In synch with rev 1.95
 
 // ========================= MPlayer help ===========================
 
 #ifdef HELP_MP_DEFINE_STATIC
-static char* banner_text=
-"\n\n"
-"MPlayer " VERSION "(C) 2000-2003 Arpad Gereoffy (siehe DOCS!)\n"
-"\n";
-
 static char help_text[]=
 "Verwendung:   mplayer [optionen] [url|verzeichnis/]dateiname\n"
 "\n"
@@ -83,7 +78,7 @@ static char help_text[]=
 #define MSGTR_TryForceAudioFmtStr "Erzwinge Audiocodecgruppe %s ...\n"
 #define MSGTR_CantFindAfmtFallback "Kann keinen Audiocodec fr gewnschte Gruppe finden, verwende anderen.\n"
 #define MSGTR_CantFindAudioCodec "Kann Codec fr Audioformat 0x%X nicht finden!\n"
-#define MSGTR_TryUpgradeCodecsConfOrRTFM "*** Versuche, %s durch etc/codecs.conf zu ersetzen.\n*** Sollte es weiterhin nicht gehen, dann lies DOCS/codecs.html!\n"
+#define MSGTR_TryUpgradeCodecsConfOrRTFM "*** Versuche, %s durch etc/codecs.conf zu ersetzen.\n*** Sollte es weiterhin nicht gehen, dann lies DOCS/German/codecs.html!\n"
 #define MSGTR_CouldntInitAudioCodec "Kann Audiocodec nicht finden! -> Kein Ton\n"
 #define MSGTR_TryForceVideoFmtStr "Erzwinge Videocodecgruppe %s ...\n"
 #define MSGTR_CantFindVideoCodec "Kann keinen Codec passend zum gewhlten -vo und Videoformat 0x%X finden!\n"
@@ -111,7 +106,7 @@ static char help_text[]=
 "  - Probiere -nocache.\n"\
 "Lies DOCS/German/video.html und DOCS/German/sound.html; dort stehen Tipps\n"\
 "und Kniffe fr optimale Einstellungen.\n"\
-"Wenn nichts davon hilft, lies DOCS/bugreports.html !\n\n"
+"Wenn nichts davon hilft, lies DOCS/German/bugreports.html !\n\n"
 
 #define MSGTR_NoGui "MPlayer wurde OHNE GUI-Untersttzung kompiliert.\n"
 #define MSGTR_GuiNeedsX "MPlayer GUI erfordert X11.\n"
@@ -139,7 +134,7 @@ static char help_text[]=
 #define MSGTR_AOComment "AO: Hinweis: %s\n"
 #define MSGTR_Video_NoVideo "Video: kein Video\n"
 #define MSGTR_NotInitializeVOPorVO "\nFATAL: Konnte Videofilter (-vop) oder Videoausgabetreiber (-vo) nicht initialisieren.\n"
-#define MSGTR_Paused "\n------ PAUSE -------\r"
+#define MSGTR_Paused "\n  =====  PAUSE  =====\r"
 #define MSGTR_PlaylistLoadUnable "\nKann Abspielliste %s nicht laden.\n"
 #define MSGTR_Exit_SIGILL_RTCpuSel \
 "- MPlayer strzte wegen einer 'illegalen Anweisung' ab.\n"\
@@ -163,7 +158,6 @@ static char help_text[]=
 "  Informationen zur Verfgung stellst.\n"
 
 // mencoder.c:
-#define MSGTR_MEncoderCopyright "(C) 2000-2003 Arpad Gereoffy (siehe DOCS!)\n"
 #define MSGTR_UsingPass3ControllFile "Verwende Pass 3 Kontrolldatei: %s\n"
 #define MSGTR_MissingFilename "\nDateiname nicht angegeben.\n\n"
 #define MSGTR_CannotOpenFile_Device "Kann Datei/Gert nicht ffnen\n"
@@ -290,7 +284,7 @@ static char help_text[]=
 #define MSGTR_CantSeekRawAVI "Kann keine RAW .AVI-Streams durchsuchen. (Index erforderlich, versuche es mit der -idx Option.)\n"
 #define MSGTR_CantSeekFile "Kann diese Datei nicht durchsuchen.\n"
 
-#define MSGTR_EncryptedVOB "Verschlsselte VOB-Datei (wurde ohne libcss Untersttzung kompiliert). Lies DOCS.\n"
+#define MSGTR_EncryptedVOB "Verschlsselte VOB-Datei (wurde ohne libcss Untersttzung kompiliert). Lies DOCS/German/cd-dvd.html.\n"
 #define MSGTR_EncryptedVOBauth "Verschlsselter Stream, jedoch wurde die Authentifizierung nicht von Dir gefordert.\n"
 
 #define MSGTR_MOVcomprhdr "MOV: Komprimierte Header werden (zur Zeit) nicht untersttzt.\n"
@@ -575,6 +569,7 @@ static char help_text[]=
 #define MSGTR_PREFERENCES_FontEncoding19 "Koreanische Schriftzeichen (CP949)"
 #define MSGTR_PREFERENCES_FontEncoding20 "Thailndische Schriftzeichen (CP874)"
 #define MSGTR_PREFERENCES_FontEncoding21 "Kyrillisch Windows (CP1251)"
+#define MSGTR_PREFERENCES_FontEncoding22 "Slavisch / Zentraleuropisch Windows (CP1250)"
 #define MSGTR_PREFERENCES_FontNoAutoScale "Kein automatische Skalierung"
 #define MSGTR_PREFERENCES_FontPropWidth "Proportional zur Breite des Films"
 #define MSGTR_PREFERENCES_FontPropHeight "Proportional zur Hhe des Films"
@@ -587,6 +582,7 @@ static char help_text[]=
 #define MSGTR_PREFERENCES_Cache "Cache ein/aus"
 #define MSGTR_PREFERENCES_CacheSize "Cachegre: "
 #define MSGTR_PREFERENCES_LoadFullscreen "im Vollbildmodus starten"
+#define MSGTR_PREFERENCES_SaveWinPos "Speichere Fensterposition"
 #define MSGTR_PREFERENCES_XSCREENSAVER "Deaktiviere XScreenSaver"
 #define MSGTR_PREFERENCES_PlayBar "Aktiviere die Playbar"
 #define MSGTR_PREFERENCES_AutoSync "AutoSync ein/aus"
