@@ -1,16 +1,15 @@
-/* Spanish translation by:
-* Leandro Lucarella <leandro at lucarella.com.ar>,
-* Jess Climent <jesus.climent at hispalinux.es>,
-* Sefanja Ruijsenaars <sefanja at gmx.net>
-* Andoni Zubimendi <andoni@lpsat.net>
-*/
+// Spanish translation by:
+// Leandro Lucarella <leandro at lucarella.com.ar>,
+// Jess Climent <jesus.climent at hispalinux.es>,
+// Sefanja Ruijsenaars <sefanja at gmx.net>
+// Andoni Zubimendi <andoni at lpsat.net>
+
+// Updated to help_mp-en.h v1.95
+
+// ========================= MPlayer help ===========================
+
 
 #ifdef HELP_MP_DEFINE_STATIC
-static char* banner_text=
-"\n\n"
-"MPlayer " VERSION "(C) 2000-2002 Arpad Gereoffy (DOCS para ms informacin)\n"
-"\n";
-
 static char help_text[]=
 "Uso:   mplayer [opciones] [url o ruta del archivo]\n"
 "\n"
@@ -132,7 +131,7 @@ static char help_text[]=
 #define MSGTR_AOComment "AO: Comentario: %s.\n"
 #define MSGTR_Video_NoVideo "Vdeo: no hay vdeo!\n"
 #define MSGTR_NotInitializeVOPorVO "\nFATAL: No se pudieron inicializar los filtros de vdeo (-vop) o de salida de vdeo (-vo)!\n"
-#define MSGTR_Paused "\n------ PAUSADO -------\r"
+#define MSGTR_Paused "\n  =====  PAUSA  =====\r"
 #define MSGTR_PlaylistLoadUnable "\nNo se puede cargar la lista de reproduccin %s.\n"
 #define MSGTR_Exit_SIGILL_RTCpuSel \
 "- MPlayer se detuvo por una 'Instruccin Ilegal'.\n"\
@@ -155,7 +154,6 @@ static char help_text[]=
 
 // mencoder.c:
 
-#define MSGTR_MEncoderCopyright "(C) 2000-2002 Arpad Gereoffy (vase DOCS!)\n"
 #define MSGTR_UsingPass3ControllFile "Usando el archivo de control pass3: %s\n"
 #define MSGTR_MissingFilename "\nFalta el nombre del archivo.\n\n"
 #define MSGTR_CannotOpenFile_Device "No se pudo abrir el archivo o el dispositivo.\n"
