@@ -2,14 +2,11 @@
 // Send me money/hw/babes!
 // ... Okay enough of the hw, now send the other two!
 
+// In synch with rev 1.95
+
 // ========================= MPlayer help ===========================
 
 #ifdef HELP_MP_DEFINE_STATIC
-static char* banner_text=
-"\n\n"
-"MPlayer " VERSION "(C) 2000-2003  Gereffy rpd  (lsd DOCS!)\n"
-"\n";
-
 static char help_text[]=
 "Indts:   mplayer [opcik] [url|tvonal/]filenv\n"
 "\n"
@@ -140,7 +137,7 @@ static char help_text[]=
 #define MSGTR_AOComment "AO: Komment: %s\n"
 #define MSGTR_Video_NoVideo "Video: nincs video!!!\n"
 #define MSGTR_NotInitializeVOPorVO "\nHIBA: Nem sikerlt a video filterek (-vop) vagy a video kimenet (-vo) inicializlsa!\n"
-#define MSGTR_Paused "\n------- SZNET -------\r"
+#define MSGTR_Paused "\n  =====  SZNET  =====\r"
 #define MSGTR_PlaylistLoadUnable "\nLejtszsi lista (%s) betltse sikertelen\n"
 #define MSGTR_Exit_SIGILL_RTCpuSel \
 "- Az MPlayer egy 'illeglis utastst' hajtott vgre.\n"\
@@ -164,7 +161,6 @@ static char help_text[]=
 
 // mencoder.c:
 
-#define MSGTR_MEncoderCopyright "(C) 2000-2003 Arpad Gereoffy (lsd DOCS!)\n"
 #define MSGTR_UsingPass3ControllFile "Pass3 file hasznlata: %s\n"
 #define MSGTR_MissingFilename "\nHinyz filenv!\n\n"
 #define MSGTR_CannotOpenFile_Device "File/eszkz megnyitsa sikertelen\n"
