@@ -2,16 +2,11 @@
 // Wszelkie uwagi i poprawki mile widziane :)
 //
 // Fixes and updates: Wojtek Kaniewski <wojtekka@bydg.pdi.net>
-// Last sync on 2003-03-29 with help_mp-en.h 1.91
+// Last sync on 2003-07-30 with help_mp-en.h 1.95
 
 // ========================= MPlayer help ===========================
 
 #ifdef HELP_MP_DEFINE_STATIC
-static char* banner_text=
-"\n\n"
-"MPlayer " VERSION "(C) 2000-2003 Arpad Gereoffy (zobacz DOCS)\n"
-"\n";
-
 static char help_text[]=
 "Uycie:   mplayer [opcje] [url|cieka/]nazwa\n"
 "\n"
@@ -139,7 +134,7 @@ static char help_text[]=
 #define MSGTR_AOComment "AO: Komentarz: %s\n"
 #define MSGTR_Video_NoVideo "Video: brak video\n"
 #define MSGTR_NotInitializeVOPorVO "\nFATAL: Nie mog zainicjowa filtrw video (-vop) lub wyjcia video (-vo).\n"
-#define MSGTR_Paused "\n================= PAUZA =================\r"
+#define MSGTR_Paused "\n  =====  PAUZA  =====\r"
 #define MSGTR_PlaylistLoadUnable "\nNie mona zaadowa playlisty %s.\n"
 #define MSGTR_Exit_SIGILL_RTCpuSel \
 "- MPlayer wykona nieprawidow operacj.\n"\
@@ -164,7 +159,6 @@ static char help_text[]=
 
 // mencoder.c:
 
-#define MSGTR_MEncoderCopyright "(C) 2000-2003 Arpad Gereoffy (zobacz DOCS)\n"
 #define MSGTR_UsingPass3ControllFile "Uywam pliku kontrolnego pass3: %s\n"
 #define MSGTR_MissingFilename "\nBrak nazwy pliku.\n\n"
 #define MSGTR_CannotOpenFile_Device "Nie mona otworzy pliku/urzdzenia.\n"
