@@ -32,7 +32,7 @@ void __builtin_delete(void* ize) {
 	free(ize);
 }
 
-#if defined(__FreeBSD__) || defined(__NetBSD__)
+#if defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__)
 void *__ctype_b=NULL;
 #endif
 
